@@ -1,5 +1,5 @@
 from .appearance import decolorize
-from .config import sethistory
+from .config import setup
 from .empty import Empty
 from .functionspace import FunctionSpace
 from .ldict_ import Ldict
