@@ -20,19 +20,23 @@
 #  part of this work is illegal and unethical regarding the effort and
 #  time spent here.
 from pathlib import Path
-from typing import TypeVar, Dict
+from typing import TypeVar, Dict, Union
+
+from ldict.persistence.disk import Disk
 
 VT = TypeVar("VT")
 
 GLOBAL = {
-    "cache": f"{Path.home()}/{'.ldict/shelve.db'}",
-    "history": False
+    "ids": True,
+    "history": False,
+    "cache": Disk(f"{Path.home()}/{'.ldict/shelve.db'}")
 }
 
 
-def setcache(cache: Dict[str, VT]):
-    GLOBAL["cache"] = cache
-
-
-def sethistory(state: bool):
-    GLOBAL["history"] = state
+def setup(ids: bool = None, history: bool = None, cache: Union[Disk, Dict[str, VT]] = None):
+    if ids is not None:
+        GLOBAL["cache"] = ids
+    if history is not None:
+        GLOBAL["history"] = history
+    if cache is not None:
+        GLOBAL["cache"] = cache
