@@ -21,12 +21,17 @@
 #  time spent here.
 
 from abc import ABC, abstractmethod
-from typing import Dict, TypeVar
+from typing import TypeVar
 
 VT = TypeVar("VT")
 
 
-class Cache(Dict[str, VT], ABC):
+class Cache(ABC):  # pragma: no cover
+
+    @abstractmethod
+    def __contains__(self, item):
+        raise NotImplementedError
+
     @abstractmethod
     def __setitem__(self, key, value):
         raise NotImplementedError
@@ -38,3 +43,19 @@ class Cache(Dict[str, VT], ABC):
     @abstractmethod
     def __delitem__(self, key):
         raise NotImplementedError
+
+    @abstractmethod
+    def __len__(self):
+        raise NotImplementedError
+
+    @abstractmethod
+    def __iter__(self):
+        raise NotImplementedError
+
+    @abstractmethod
+    def __repr__(self):
+        raise NotImplementedError
+
+    @abstractmethod
+    def copy(self):
+        raise NotImplementedError
